-------------------------------------------------------
--RADIOSITY SETTINGS MANAGER
--Version:      0.21
--Started:      01/07/2002 
--Last Changed: 08/05/2002 
--Code by:      Borislav 'Bobo' Petrov
--Email:        bobo@email.archlab.tuwien.ac.at
-------------------------------------------------------
--This file belongs to \Scripts\Startup
-------------------------------------------------------
--Version 0.21
--*Double-click does not close Restore dialog
--*Renamed buttons
-------------------------------------------------------
--Version 0.2
--*Last position of both dialogs will be stored 
--*Solver Type of each setup will be displayed
--*New option to delete setups from the Restore dialog
-------------------------------------------------------


struct RadiositySettingsManager
(
fn StoreSettings FileName =
(
	file_name = ((GetDir #plugcfg)+"/"+FileName+".rsm")										--build setup file name
	out_file = createfile file_name 														--create output filestream
	format "%\n" (substring (SceneRadiosity.radiosity as string) 17 100) to:out_file  		--write the solver type to file
	props_array = getpropnames SceneRadiosity.radiosity										--get all props of the current solver
	for i in props_array do																	--loop through all properties
	(
		format "% %\n" (i as string) (getProperty SceneRadiosity.radiosity i) to:out_file 	--write property name and value to file
	)
	close out_file																			
),	
fn RestoreSettings FileName =
(
	file_name = ((GetDir #plugcfg)+"/"+FileName+".rsm")										--build setup file name
	in_file = openfile file_name 															--open file 
	str = readline in_file 																	--read first line from file
	local success = false																	--init. a flag to false
	try
	(
		SceneRadiosity.radiosity = execute (str+"()")										--try to set current solver to the type from the file
		success = true																		--set flag to true if succeeded
	)
	catch()																					
	if success then																			--if flag is true, go on...
	(	
		while not eof in_file do															--read until the end of file
		(
			try
			(
				propName = (readDelimitedString in_file " ") as name						--read the property name
				propValue = readvalue in_file 												--read the property value
				setProperty SceneRadiosity.radiosity propName propValue 					--try to set the property in the solver
			)catch()	
		)
	)
	else
	(
		messagebox "CANNOT LOAD:\nProbably An Outdated Setup!" title:"Radiosity Settings Manager"
	)	
	close in_file
)
)--end struct



macroscript RSM_StoreSettings
	category:"Radiosity Settings" 
	buttontext:"StoreRadSettings" 
	tooltip:"Store Radiosity Settings"
(
	setup_position = [200.0,200.0]	
	ini_file = openfile ((GetDir #plugcfg)+"/RSM_Store.ini")
	if ini_file != undefined then
	(
		setup_position = execute (readline ini_file)
		close ini_file
	)
	setup_number = ((getFiles((GetDir #plugcfg)+"/Rad_" +(getfilenamefile MaxFileName) +"_*.rsm")).count+1) as string 			--Check for existing setup names and build a number string
	rollout Store_Rollout "Store Radiosity Settings:"									
	(
		edittext setup_name text:("Rad_"+ (getfilenamefile MaxFileName) +"_"+ setup_number)										--Set the edit text field to the name suggestion
		button execute_operation "SAVE" width:110 across:2 align:#left							
		button cancel_operation "Cancel" width:110 align:#right									
		on cancel_operation pressed do DestroyDialog Store_Rollout	
		on execute_operation pressed do
		(
			if setup_name.text != "" then																						--if the name is not empty string...
			(
				local q = false																									--init a flag to false
				if (getFiles((GetDir #plugcfg)+"/"+setup_name.text+".rsm")).count == 0 then										--if no such file exists...
				(
					q = true																									--set flag to true
				)
				else
				(
					q = querybox "A Setup with the same name already exists.\nOverwrite?" title:"Radiosity Settings Manager"	--warn about existing file
				)	
				if q then RadiositySettingsManager.StoreSettings setup_name.text												--if flag is true, store the setup
			)	
			DestroyDialog Store_Rollout																							--close dialog
		)
		on Store_Rollout moved pos do 
		(
			ini_file = createfile ((GetDir #plugcfg)+"/RSM_Store.ini")
			format "%\n" pos to:ini_file
			close ini_file
		)		
	)--end rollout
    actionMan.executeAction 1195574973 "102"																					--open the Radiosity setup dialog
	if SceneRadiosity.radiosity != undefined then 																				--if the current solver is not undefined...
	(
		CreateDialog Store_Rollout height:50 width:250 modal:false pos:setup_position											--open the script's dialog
	)	
	else
	(
		messagebox "Please Select a Radiosity Solver!" title:"Radiosity Settings Manager"										--suggest setting a slover first
	)
)--end macro

macroscript RSM_RestoreSettings
	category:"Radiosity Settings" 
	buttontext:"RestoreRadSettings" 
	tooltip:"Restore Radiosity Settings"
(
	setup_position = [200.0,200.0]	
	ini_file = openfile ((GetDir #plugcfg)+"/RSM_Restore.ini")
	if ini_file != undefined then
	(
		setup_position = execute (readline ini_file)
		close ini_file
	)
	
	file_names = #()	
	file_paths = #()
	files_array = #()																											--init. an array for setup names
	fn collectFileNames =
	(	
		file_names = #()																										--init. an array for setup names
		files_array = getFiles((GetDir #plugcfg)+"/*.rsm")																		--get all files of type .rsm
		for i = files_array.count to 1 by -1 do 																				--loop backwards
		(
			setup_type = ""
			try
			(
				temp_file = openfile files_array[i]
				setup_type = readline temp_file
				close temp_file
			)
			catch()
			append file_names ((getfilenamefile files_array[i])	+ " : " + setup_type)											--collect file names in an array of strings in reverse order
			append file_paths (getfilenamefile files_array[i])
		)--end loop
	)--end fn	
	collectFileNames()
	
	rollout Restore_Rollout "Restore Radiosity Settings:"									
	(
		listbox setup_names items:file_names
		button execute_operation "Load & Close" width:105 across:3 align:#left enabled:(file_names.count != 0)							--enable button only if any setups found
		button delete_operation "Delete" width:105 align:#center enabled:(file_names.count != 0)							
		button cancel_operation "Close" width:105 align:#right	
		
		fn RestoreSettings =
		(
			RadiositySettingsManager.RestoreSettings file_paths[setup_names.selection]
		)
		
		on cancel_operation pressed do DestroyDialog Restore_Rollout	
		on delete_operation pressed do 
		(
			q = querybox "This will remove the Setup permanently.\nAre you sure?" title:"Radiosity Settings Manager"
			if q then
			(
				deleteFile ((GetDir #plugcfg)+"/"+file_paths[setup_names.selection]+".rsm") 
				collectFileNames()
				setup_names.items = file_names
			)
		)
		
		on setup_names doubleclicked itm do
		(
			RestoreSettings()
		)	
		on execute_operation pressed do 
		(
			RestoreSettings()
			DestroyDialog Restore_Rollout	
		)	
		on Restore_Rollout moved pos do 
		(
			ini_file = createfile ((GetDir #plugcfg)+"/RSM_Restore.ini")
			format "%\n" pos to:ini_file
			close ini_file
		)
	)--end rollout
	
	CreateDialog Restore_Rollout height:170 width:350 modal:false pos:setup_position											--create the script's dialog
	actionMan.executeAction 1195574973 "102"																					--open the Radiosity Dialog
)--end macro
